rpaframework-google
===================

This library enables Google Cloud services for `RPA Framework`_
libraries, such as Google Sheets and Google Vision.

.. _RPA Framework: https://rpaframework.org
